summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorAaron Patterson <aaron.patterson@gmail.com>2009-09-26 21:42:03 -0700
committerAaron Patterson <aaron.patterson@gmail.com>2009-09-26 21:42:03 -0700
commit850df20bf83d182703d075951bfb95fb4531748a (patch)
tree31b0fa124ab273b1fa2b3d9b2531dc8782f6c519 /lib
parente2dc5ad3f9b8da92fce87d049d1a3681ba52adb8 (diff)
downloadpsych-850df20bf83d182703d075951bfb95fb4531748a.zip
start docuemnt flushed out
Diffstat (limited to 'lib')
-rw-r--r--lib/psych/parser/handler.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/psych/parser/handler.rb b/lib/psych/parser/handler.rb
index a140b09..211ebf1 100644
--- a/lib/psych/parser/handler.rb
+++ b/lib/psych/parser/handler.rb
@@ -9,9 +9,9 @@ module Psych
end
###
- # Called when the document starts with the declared +version+ and
- # +tag_directives+
- def start_document version = [], tag_directives = []
+ # Called when the document starts with the declared +version+,
+ # +tag_directives+, if the document is +implicit+
+ def start_document version = [], tag_directives = [], implicit = true
end
###